@@ -84,6 +84,7 @@ __all__ = (
     "DocumentStatusType",
     "DocumentTypeType",
     "ExecutionModeType",
+    "ExternalAlarmStateType",
     "FaultType",
     "GetInventoryPaginatorName",
     "GetInventorySchemaPaginatorName",
@@ -304,6 +305,7 @@ DocumentTypeType = Literal[
     "Session",
 ]
 ExecutionModeType = Literal["Auto", "Interactive"]
+ExternalAlarmStateType = Literal["ALARM", "UNKNOWN"]
 FaultType = Literal["Client", "Server", "Unknown"]
 GetInventoryPaginatorName = Literal["get_inventory"]
 GetInventorySchemaPaginatorName = Literal["get_inventory_schema"]
@@ -359,6 +361,7 @@ NotificationTypeType = Literal["Command", "Invocation"]
 OperatingSystemType = Literal[
     "AMAZON_LINUX",
     "AMAZON_LINUX_2",
+    "AMAZON_LINUX_2022",
     "CENTOS",
     "DEBIAN",
     "MACOS",
@@ -582,6 +585,7 @@ ServiceName = Literal[
     "connect",
     "connect-contact-lens",
     "connectcampaigns",
+    "connectcases",
     "connectparticipant",
     "controltower",
     "cur",
@@ -661,6 +665,7 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
@@ -716,6 +721,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
